@@ -16,6 +16,7 @@
 #' @export
 roadoi_addin <- function() {
   # nocov start
+  # nolint start
   # create user interface like the one rcrossref provides
   ui <- miniUI::miniPage(
     miniUI::gadgetTitleBar("Find freely available full-text via Unpaywall"),
@@ -27,6 +28,15 @@ roadoi_addin <- function() {
         in the text box below. Please note that only the first ten DOIs will
         be fetched."
       ),
+      shiny::textAreaInput(
+        inputId = "email",
+        label = "Please add your email address",
+        value = ifelse(
+          !is.null(getOption("roadoi_email")),
+          getOption("roadoi_email"),
+          "Enter your email ..."
+        )
+      ),
       shiny::textAreaInput(
         inputId = "text",
         label = "DOIs (line separated):",
@@ -37,12 +47,10 @@ roadoi_addin <- function() {
       shiny::tableOutput("table"),
       shiny::tags$hr(),
       shiny::tags$p(
-        "Free full-text links from ",
+        "Free full-text links from Unpaywall",
         shiny::tags$a(
-          shiny::tags$img(
-            src = "http://unpaywall.org/static/img/logo-green.png"
-            ),
-          href = "http://unpaywall.org/"
+          shiny::tags$img(src = "https://raw.githubusercontent.com/Impactstory/unpaywall/master/static/img/icon-128.png"),
+          href = "https://unpaywall.org/"
         ),
         align = "right"
       )
@@ -62,11 +70,8 @@ roadoi_addin <- function() {
         if (length(dois) > 9)
           dois <- dois[1:10]
         # prepare API call
-        email <- ifelse(!is.null(getOption("roadoi_email")),
-                        getOption("roadoi_email"),
-                        "name@example.com")
         # fetch full-text links and return the best match
-        tt <- roadoi::oadoi_fetch(dois, email)
+        tt <- roadoi::oadoi_fetch(dois, input$email)
         if (any(tt$is_oa)) {
           tt %>%
             tidyr::unnest(best_oa_location) %>%
@@ -100,7 +105,6 @@ roadoi_addin <- function() {
 }
 
 # helper to make links clickable
-# nolint start
 create_link <- function(x) {
   paste0('<a href="', x, '" target="_blank">', x, '</a>')
 }
